@@ -193,14 +193,20 @@ Clef_engraver::stop_translation_timestep ()
 
 ADD_ACKNOWLEDGER (Clef_engraver, bar_line);
 ADD_TRANSLATOR (Clef_engraver,
-		/* doc */ "Determine and set reference point for pitches",
-		/* create */ "Clef "
+		/* doc */
+		"Determine and set reference point for pitches.",
+
+		/* create */
+		"Clef "
 		"OctavateEight ",
+
 		/* read */
 		"clefGlyph "
 		"clefOctavation "
 		"clefPosition "
 		"explicitClefVisibility "
-		"forceClef "
-		,
-		/* write */ "");
+		"forceClef ",
+
+		/* write */
+		""
+		);
