@@ -89,9 +89,11 @@ Lyric_extender::print (SCM smob)
 }
 
 ADD_INTERFACE (Lyric_extender,
-	       "The extender is a simple line at the baseline of the lyric "
-	       "that helps show the length of a melissima (tied/slurred note).",
+	       "The extender is a simple line at the baseline of the lyric"
+	       " that helps show the length of a melisma (a tied or slurred"
+	       " note).",
 
+	       /* properties */
 	       "heads "
 	       "left-padding "
 	       "next "
