@@ -10,18 +10,10 @@
 #include "warn.hh"
 #include "ly-smobs.icc"
 
-Spring_smob::Spring_smob ()
-{
-  distance_ = 0.;
-  inverse_strength_ = 1.0;
-  expand_only_b_ = false;
-  other_ = 0;
-}
-
-IMPLEMENT_SIMPLE_SMOBS (Spring_smob);
+IMPLEMENT_SIMPLE_SMOBS (Spring);
 
 SCM
-Spring_smob::mark_smob (SCM x)
+Spring::mark_smob (SCM x)
 {
   (void)x;
 
@@ -29,14 +21,14 @@ Spring_smob::mark_smob (SCM x)
 }
 
 int
-Spring_smob::print_smob (SCM, SCM p, scm_print_state *)
+Spring::print_smob (SCM, SCM p, scm_print_state *)
 {
   scm_puts ("#<Spring smob>", p);
   return 1;
 }
 
 SCM
-Spring_smob::equal_p (SCM a, SCM b)
+Spring::equal_p (SCM a, SCM b)
 {
   return a == b? SCM_BOOL_T : SCM_BOOL_F;
 }
